use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Anwar
Book
CLI
Chris
Dan
Etheridge
Karen
Kelly
Kensho
Lapworth
Leir
Leo
Mohammad
Müller
Nehren
Olaf
Prather
Rachel
Rick
Shawn
Sorichetti
Task
Tina
apeiron
chris
cpan2
ether
grinnz
irc
leo
lib
mohammad
olaf
rkellyalso
rleir
shawn
